"""Testes de bindings de Web Services do SIFEN."""
import warnings

warnings.filterwarnings("ignore")


class TestWsRecepcion:
    """Testes de schemas de recepção."""

    def test_import_ws_recep_de(self):
        from pysifen.de.bindings.v150.ws_si_recep_de_v150 import (
            REnviDe,
            RRetEnviDe,
        )

        assert hasattr(REnviDe, "__dataclass_fields__")
        assert hasattr(RRetEnviDe, "__dataclass_fields__")

    def test_import_ws_recep_evento(self):
        from pysifen.de.bindings.v150.ws_si_recep_evento_v150 import (
            REnviEventoDe,
            RRetEnviEventoDe,
        )

        assert hasattr(REnviEventoDe, "__dataclass_fields__")
        assert hasattr(RRetEnviEventoDe, "__dataclass_fields__")

    def test_import_ws_recep_lote(self):
        from pysifen.de.bindings.v150.ws_si_recep_lote_de_v141 import (
            REnvioLote,
            RResEnviLoteDe,
        )

        assert hasattr(REnvioLote, "__dataclass_fields__")
        assert hasattr(RResEnviLoteDe, "__dataclass_fields__")


class TestWsConsulta:
    """Testes de schemas de consulta."""

    def test_import_cons_de(self):
        from pysifen.de.bindings.v150.ws_si_cons_de_v141 import (
            REnviConsDeRequest,
            REnviConsDeResponse,
        )

        assert hasattr(REnviConsDeRequest, "__dataclass_fields__")
        assert hasattr(REnviConsDeResponse, "__dataclass_fields__")

    def test_import_cons_lote(self):
        from pysifen.de.bindings.v150.ws_si_cons_lote_v141 import (
            REnviConsLoteDe,
            RResEnviConsLoteDe,
        )

        assert hasattr(REnviConsLoteDe, "__dataclass_fields__")
        assert hasattr(RResEnviConsLoteDe, "__dataclass_fields__")

    def test_import_cons_ruc(self):
        from pysifen.de.bindings.v150.ws_si_cons_ruc_v141 import (
            REnviConsRuc,
            RResEnviConsRuc,
        )

        assert hasattr(REnviConsRuc, "__dataclass_fields__")
        assert hasattr(RResEnviConsRuc, "__dataclass_fields__")

    def test_import_cons_dte(self):
        from pysifen.de.bindings.v150.ws_si_cons_dte import (
            RConsDteRequest,
            RConsDteResponse,
        )

        assert hasattr(RConsDteRequest, "__dataclass_fields__")
        assert hasattr(RConsDteResponse, "__dataclass_fields__")


class TestWsProtocolo:
    """Testes de schemas de protocolo."""

    def test_import_prot_de(self):
        from pysifen.de.bindings.v150.prot_proces_de_v150 import RProtDe

        assert hasattr(RProtDe, "__dataclass_fields__")

    def test_import_prot_eventos(self):
        from pysifen.de.bindings.v150.prot_proces_eventos_v141 import (
            TgResProc,
            TgResProcEve,
        )

        assert hasattr(TgResProc, "__dataclass_fields__")
        assert hasattr(TgResProcEve, "__dataclass_fields__")


class TestWsMixin:
    """Verifica que CommonMixin está nas classes WS."""

    def test_ws_has_mixin(self):
        from pysifen.de.bindings.v150.ws_si_recep_de_v150 import REnviDe

        assert hasattr(REnviDe, "from_xml")
        assert hasattr(REnviDe, "to_xml")
        assert hasattr(REnviDe, "from_path")



from __future__ import annotations

from enum import Enum

__NAMESPACE__ = "http://ekuatia.set.gov.py/sifen/xsd"


class TcUniMed(Enum):
    """
    :cvar VALUE_87: Metros - m
    :cvar VALUE_2366: Costo Por Mil - CPM
    :cvar VALUE_2329: Unidad Internacional - UI
    :cvar VALUE_110: Metros cúbicos - M3
    :cvar VALUE_77: Unidad - UNI
    :cvar VALUE_86: Gramos - g
    :cvar VALUE_89: Litros - LT
    :cvar VALUE_90: Miligramos - MG
    :cvar VALUE_91: Centimetros - CM
    :cvar VALUE_92: Centimetros cuadrados - CM2
    :cvar VALUE_93: Centimetros cubicos - CM3
    :cvar VALUE_94: Pulgadas - PUL
    :cvar VALUE_96: Milímetros cuadrados - MM2
    :cvar VALUE_79: Kilogramos s/ metro cuadrado - kg/m2
    :cvar VALUE_97: Año - AA
    :cvar VALUE_98: Mes - ME
    :cvar VALUE_99: Tonelada - TN
    :cvar VALUE_100: Hora - Hs
    :cvar VALUE_101: Minuto - Mi
    :cvar VALUE_104: Determinación - DET
    :cvar VALUE_103: Yardas - Ya
    :cvar VALUE_108: Metros - MT
    :cvar VALUE_109: Metros cuadrados - M2
    :cvar VALUE_95: Milímetros - MM
    :cvar VALUE_666: Segundo - Se
    :cvar VALUE_102: Día - Di
    :cvar VALUE_83: Kilogramos - kg
    :cvar VALUE_88: Mililitros - ML
    :cvar VALUE_625: Kilómetros - Km
    :cvar VALUE_660: Metro lineal - ml
    :cvar VALUE_885: Unidad Medida Global - GL
    :cvar VALUE_891: Por Milaje - pm
    :cvar VALUE_869: Hectáreas - ha
    :cvar VALUE_569: Ración - ración
    :cvar VALUE_111: Bovinas - 4A
    :cvar VALUE_112: Curie - Ci
    :cvar VALUE_113: Docena - DOC
    :cvar VALUE_114: Galones (US) (3,7843 LT) - GLL
    :cvar VALUE_115: Gruesas - GRO
    :cvar VALUE_116: Kilogramo Bruto - E4
    :cvar VALUE_117: Kits - KT
    :cvar VALUE_118: Microcurie - M5
    :cvar VALUE_119: Milicurie - MCU
    :cvar VALUE_120: Millar - MIL
    :cvar VALUE_121: Par - PAR
    :cvar VALUE_122: Pies - FOT
    :cvar VALUE_123: Pies Cuadradas - FTK
    :cvar VALUE_124: Piezas - PCE
    :cvar VALUE_125: Quilate - KLT
    :cvar VALUE_126: Resmas - RM
    :cvar VALUE_127: Rollos - RO
    :cvar VALUE_128: 1000 Kilowatt Hora - kWh
    :cvar VALUE_129: Mazos - U(JGO)
    :cvar VALUE_130: Tambores - DR
    :cvar VALUE_131: Caja - BX
    :cvar VALUE_132: Juego - SET
    :cvar VALUE_133: Paquete - PK
    :cvar VALUE_134: Bolsa - BG
    :cvar VALUE_135: Docena Par - DPC
    :cvar VALUE_136: Pote - JR
    :cvar VALUE_137: Fardos - BL
    :cvar VALUE_138: Bulto - AB
    :cvar VALUE_139: Cesta - BK
    :cvar VALUE_140: Peso Base - BW
    """

    VALUE_87 = 87
    VALUE_2366 = 2366
    VALUE_2329 = 2329
    VALUE_110 = 110
    VALUE_77 = 77
    VALUE_86 = 86
    VALUE_89 = 89
    VALUE_90 = 90
    VALUE_91 = 91
    VALUE_92 = 92
    VALUE_93 = 93
    VALUE_94 = 94
    VALUE_96 = 96
    VALUE_79 = 79
    VALUE_97 = 97
    VALUE_98 = 98
    VALUE_99 = 99
    VALUE_100 = 100
    VALUE_101 = 101
    VALUE_104 = 104
    VALUE_103 = 103
    VALUE_108 = 108
    VALUE_109 = 109
    VALUE_95 = 95
    VALUE_666 = 666
    VALUE_102 = 102
    VALUE_83 = 83
    VALUE_88 = 88
    VALUE_625 = 625
    VALUE_660 = 660
    VALUE_885 = 885
    VALUE_891 = 891
    VALUE_869 = 869
    VALUE_569 = 569
    VALUE_111 = 111
    VALUE_112 = 112
    VALUE_113 = 113
    VALUE_114 = 114
    VALUE_115 = 115
    VALUE_116 = 116
    VALUE_117 = 117
    VALUE_118 = 118
    VALUE_119 = 119
    VALUE_120 = 120
    VALUE_121 = 121
    VALUE_122 = 122
    VALUE_123 = 123
    VALUE_124 = 124
    VALUE_125 = 125
    VALUE_126 = 126
    VALUE_127 = 127
    VALUE_128 = 128
    VALUE_129 = 129
    VALUE_130 = 130
    VALUE_131 = 131
    VALUE_132 = 132
    VALUE_133 = 133
    VALUE_134 = 134
    VALUE_135 = 135
    VALUE_136 = 136
    VALUE_137 = 137
    VALUE_138 = 138
    VALUE_139 = 139
    VALUE_140 = 140


class TdDesUniMed(Enum):
    """
    :cvar M: Metros
    :cvar CPM: Costo Por Mil
    :cvar UI: Unidad Internacional
    :cvar M3: Metros cúbicos
    :cvar UNI: Unidad
    :cvar G: Gramos
    :cvar LT: Litros
    :cvar MG: Miligramos
    :cvar CM: Centimetros
    :cvar CM2: Centimetros cuadrados
    :cvar CM3: Centimetros cubicos
    :cvar PUL: Pulgadas
    :cvar MM2: Milímetros cuadrados
    :cvar KG_M2: Kilogramos s/ metro cuadrado
    :cvar AA: Año
    :cvar ME: Mes
    :cvar TN: Tonelada
    :cvar HS: Hora
    :cvar MI: Minuto
    :cvar DET: Determinación
    :cvar YA: Yardas
    :cvar MT: Metros
    :cvar M2: Metros cuadrados
    :cvar MM: Milímetros
    :cvar SE: Segundo
    :cvar DI: Día
    :cvar KG: Kilogramos
    :cvar ML: Mililitros
    :cvar KM: Kilómetros
    :cvar ML_1: Metro lineal
    :cvar GL: Unidad Medida Global
    :cvar PM: Por Milaje
    :cvar HA: Hectáreas
    :cvar RACI_N: Ración
    :cvar VALUE_4_A: Bovinas
    :cvar CI: Curie
    :cvar DOC: Docena
    :cvar GLL: Galones (US) (3,7843 LT)
    :cvar GRO: Gruesas
    :cvar E4: Kilogramo Bruto
    :cvar KT: Kits
    :cvar M5: Microcurie
    :cvar MCU: Milicurie
    :cvar MIL: Millar
    :cvar PAR: Par
    :cvar FOT: Pies
    :cvar FTK: Pies Cuadradas
    :cvar PCE: Piezas
    :cvar KLT: Quilate
    :cvar RM: Resmas
    :cvar RO: Rollos
    :cvar K_WH: 1000 Kilowatt Hora
    :cvar U_JGO: Mazos
    :cvar DR: Tambores
    :cvar BX: Caja
    :cvar SET: Juego
    :cvar PK: Paquete
    :cvar BG: Bolsa
    :cvar DPC: Docena Par
    :cvar JR: Pote
    :cvar BL: Fardos
    :cvar AB: Bulto
    :cvar BK: Cesta
    :cvar BW: Peso Base
    """

    M = "m"
    CPM = "CPM"
    UI = "UI"
    M3 = "M3"
    UNI = "UNI"
    G = "g"
    LT = "LT"
    MG = "MG"
    CM = "CM"
    CM2 = "CM2"
    CM3 = "CM3"
    PUL = "PUL"
    MM2 = "MM2"
    KG_M2 = "kg/m2"
    AA = "AA"
    ME = "ME"
    TN = "TN"
    HS = "Hs"
    MI = "Mi"
    DET = "DET"
    YA = "Ya"
    MT = "MT"
    M2 = "M2"
    MM = "MM"
    SE = "Se"
    DI = "Di"
    KG = "kg"
    ML = "ML"
    KM = "Km"
    ML_1 = "ml"
    GL = "GL"
    PM = "pm"
    HA = "ha"
    RACI_N = "ración"
    VALUE_4_A = "4A"
    CI = "Ci"
    DOC = "DOC"
    GLL = "GLL"
    GRO = "GRO"
    E4 = "E4"
    KT = "KT"
    M5 = "M5"
    MCU = "MCU"
    MIL = "MIL"
    PAR = "PAR"
    FOT = "FOT"
    FTK = "FTK"
    PCE = "PCE"
    KLT = "KLT"
    RM = "RM"
    RO = "RO"
    K_WH = "kWh"
    U_JGO = "U(JGO)"
    DR = "DR"
    BX = "BX"
    SET = "SET"
    PK = "PK"
    BG = "BG"
    DPC = "DPC"
    JR = "JR"
    BL = "BL"
    AB = "AB"
    BK = "BK"
    BW = "BW"



from __future__ import annotations

from enum import Enum

__NAMESPACE__ = "http://ekuatia.set.gov.py/sifen/xsd"


class PaisType(Enum):
    """
    :cvar MKD: Macedonia del Norte
    :cvar TWN: Taiwán (Provincia de China)
    :cvar DZA: Argelia
    :cvar EGY: Egipto
    :cvar LBY: Libia
    :cvar MAR: Marruecos
    :cvar SDN: Sudán
    :cvar TUN: Túnez
    :cvar ESH: Sáhara Occidental
    :cvar IOT: Territorio Británico del Océano Índico
    :cvar BDI: Burundi
    :cvar COM: Comoras
    :cvar DJI: Djibouti
    :cvar ERI: Eritrea
    :cvar ETH: Etiopía
    :cvar ATF: Territorio de las Tierras Australes Francesas
    :cvar KEN: Kenya
    :cvar MDG: Madagascar
    :cvar MWI: Malawi
    :cvar MUS: Mauricio
    :cvar MYT: Mayotte
    :cvar MOZ: Mozambique
    :cvar REU: Reunión
    :cvar RWA: Rwanda
    :cvar SYC: Seychelles
    :cvar SOM: Somalia
    :cvar SSD: Sudán del Sur
    :cvar UGA: Uganda
    :cvar TZA: República Unida de Tanzanía
    :cvar ZMB: Zambia
    :cvar ZWE: Zimbabwe
    :cvar AGO: Angola
    :cvar CMR: Camerún
    :cvar CAF: República Centroafricana
    :cvar TCD: Chad
    :cvar COG: Congo
    :cvar COD: República Democrática del Congo
    :cvar GNQ: Guinea Ecuatorial
    :cvar GAB: Gabón
    :cvar STP: Santo Tomé y Príncipe
    :cvar BWA: Botswana
    :cvar LSO: Lesotho
    :cvar NAM: Namibia
    :cvar ZAF: Sudáfrica
    :cvar SWZ: Swazilandia
    :cvar BEN: Benin
    :cvar BFA: Burkina Faso
    :cvar CPV: Cabo Verde
    :cvar CIV: Côte d'Ivoire
    :cvar GMB: Gambia
    :cvar GHA: Ghana
    :cvar GIN: Guinea
    :cvar GNB: Guinea-Bissau
    :cvar LBR: Liberia
    :cvar MLI: Malí
    :cvar MRT: Mauritania
    :cvar NER: Níger
    :cvar NGA: Nigeria
    :cvar SHN: Santa Elena
    :cvar SEN: Senegal
    :cvar SLE: Sierra Leona
    :cvar TGO: Togo
    :cvar AIA: Anguila
    :cvar ATG: Antigua y Barbuda
    :cvar ABW: Aruba
    :cvar BHS: Bahamas
    :cvar BRB: Barbados
    :cvar BES: Bonaire, San Eustaquio y Saba
    :cvar VGB: Islas Vírgenes Británicas
    :cvar CYM: Islas Caimán
    :cvar CUB: CUBA
    :cvar CUW: Curaçao
    :cvar DMA: Dominica
    :cvar DOM: República Dominicana
    :cvar GRD: Granada
    :cvar GLP: Guadalupe
    :cvar HTI: Haití
    :cvar JAM: Jamaica
    :cvar MTQ: Martinica
    :cvar MSR: Montserrat
    :cvar PRI: Puerto Rico
    :cvar BLM: San Bartolomé
    :cvar KNA: Saint Kitts y Nevis
    :cvar LCA: Santa Lucía
    :cvar MAF: San Martín (parte francesa)
    :cvar VCT: San Vicente y las Granadinas
    :cvar SXM: San Martín (parte holandés)
    :cvar TTO: Trinidad y Tabago
    :cvar TCA: Islas Turcas y Caicos
    :cvar VIR: Islas Vírgenes de los Estados Unidos
    :cvar BLZ: Belice
    :cvar CRI: Costa Rica
    :cvar SLV: El Salvador
    :cvar GTM: Guatemala
    :cvar HND: Honduras
    :cvar MEX: México
    :cvar NIC: Nicaragua
    :cvar PAN: Panamá
    :cvar ARG: Argentina
    :cvar BOL: Bolivia (Estado Plurinacional de)
    :cvar BRA: Brasil
    :cvar CHL: Chile
    :cvar COL: Colombia
    :cvar ECU: Ecuador
    :cvar FLK: Islas Malvinas (Falkland)
    :cvar GUF: Guayana Francesa
    :cvar GUY: Guyana
    :cvar PRY: Paraguay
    :cvar PER: Perú
    :cvar SGS: Georgia del Sur y las Islas Sandwich del Sur
    :cvar SUR: Suriname
    :cvar URY: Uruguay
    :cvar VEN: Venezuela (República Bolivariana de)
    :cvar BMU: Bermuda
    :cvar CAN: Canadá
    :cvar GRL: Groenlandia
    :cvar SPM: Saint Pierre y Miquelon
    :cvar USA: Estados Unidos de América
    :cvar ATA: Antártida
    :cvar KAZ: Kazajstán
    :cvar KGZ: Kirguistán
    :cvar TJK: Tayikistán
    :cvar TKM: Turkmenistán
    :cvar UZB: Uzbekistán
    :cvar CHN: China
    :cvar HKG: Hong Kong
    :cvar MAC: Macao
    :cvar PRK: República Popular Democrática de Corea
    :cvar JPN: Japón
    :cvar MNG: Mongolia
    :cvar KOR: República de Corea
    :cvar BRN: Brunei Darussalam
    :cvar KHM: Camboya
    :cvar IDN: Indonesia
    :cvar LAO: República Democrática Popular Lao
    :cvar MYS: Malasia
    :cvar MMR: Myanmar
    :cvar PHL: Filipinas
    :cvar SGP: Singapur
    :cvar THA: Tailandia
    :cvar TLS: Timor-Leste
    :cvar VNM: Viet Nam
    :cvar AFG: Afganistán
    :cvar BGD: Bangladesh
    :cvar BTN: Bhután
    :cvar IND: India
    :cvar IRN: Irán (República Islámica del)
    :cvar MDV: Maldivas
    :cvar NPL: Nepal
    :cvar PAK: Pakistán
    :cvar LKA: Sri Lanka
    :cvar ARM: Armenia
    :cvar AZE: Azerbaiyán
    :cvar BHR: Bahrein
    :cvar CYP: Chipre
    :cvar GEO: Georgia
    :cvar IRQ: Iraq
    :cvar ISR: Israel
    :cvar JOR: Jordania
    :cvar KWT: Kuwait
    :cvar LBN: Líbano
    :cvar OMN: Omán
    :cvar QAT: Qatar
    :cvar SAU: Arabia Saudita
    :cvar PSE: Estado de Palestina
    :cvar SYR: República Árabe Siria
    :cvar TUR: Turquía
    :cvar ARE: Emiratos Árabes Unidos
    :cvar YEM: Yemen
    :cvar BLR: Belarús
    :cvar BGR: Bulgaria
    :cvar CZE: Chequia
    :cvar HUN: Hungría
    :cvar POL: Polonia
    :cvar MDA: República de Moldova
    :cvar ROU: Rumania
    :cvar RUS: Federación de Rusia
    :cvar SVK: Eslovaquia
    :cvar UKR: Ucrania
    :cvar ALA: Islas Åland
    :cvar GGY: Guernsey
    :cvar JEY: Jersey
    :cvar DNK: Dinamarca
    :cvar EST: Estonia
    :cvar FRO: Islas Feroe
    :cvar FIN: Finlandia
    :cvar ISL: Islandia
    :cvar IRL: Irlanda
    :cvar IMN: Isla de Man
    :cvar LVA: Letonia
    :cvar LTU: Lituania
    :cvar NOR: Noruega
    :cvar SJM: Islas Svalbard y Jan Mayen
    :cvar SWE: Suecia
    :cvar GBR: Reino Unido de Gran Bretaña e Irlanda del Norte
    :cvar ALB: Albania
    :cvar AND: Andorra
    :cvar BIH: Bosnia y Herzegovina
    :cvar HRV: Croacia
    :cvar GIB: Gibraltar
    :cvar GRC: Grecia
    :cvar VAT: Santa Sede
    :cvar ITA: Italia
    :cvar MLT: Malta
    :cvar MNE: Montenegro
    :cvar PRT: Portugal
    :cvar SMR: San Marino
    :cvar SRB: Serbia
    :cvar SVN: Eslovenia
    :cvar ESP: España
    :cvar AUT: Austria
    :cvar BEL: Bélgica
    :cvar FRA: Francia
    :cvar DEU: Alemania
    :cvar LIE: Liechtenstein
    :cvar LUX: Luxemburgo
    :cvar MCO: Mónaco
    :cvar NLD: Países Bajos
    :cvar CHE: Suiza
    :cvar AUS: Australia
    :cvar CXR: Isla de Navidad
    :cvar CCK: Islas Cocos (Keeling)
    :cvar HMD: Islas Heard y McDonald
    :cvar NZL: Nueva Zelandia
    :cvar NFK: Islas Norfolk
    :cvar FJI: Fiji
    :cvar NCL: Nueva Caledonia
    :cvar PNG: Papua Nueva Guinea
    :cvar SLB: Islas Salomón
    :cvar VUT: Vanuatu
    :cvar GUM: Guam
    :cvar KIR: Kiribati
    :cvar MHL: Islas Marshall
    :cvar FSM: Micronesia (Estados Federados de)
    :cvar NRU: Nauru
    :cvar MNP: Islas Marianas Septentrionales
    :cvar PLW: Palau
    :cvar UMI: Islas menores alejadas de Estados Unidos
    :cvar ASM: Samoa Americana
    :cvar COK: Islas Cook
    :cvar PYF: Polinesia Francesa
    :cvar NIU: Niue
    :cvar PCN: Pitcairn
    :cvar WSM: Samoa
    :cvar TKL: Tokelau
    :cvar TON: Tonga
    :cvar TUV: Tuvalu
    :cvar WLF: Islas Wallis y Futuna
    :cvar NN: NO EXISTE
    """

    MKD = "MKD"
    TWN = "TWN"
    DZA = "DZA"
    EGY = "EGY"
    LBY = "LBY"
    MAR = "MAR"
    SDN = "SDN"
    TUN = "TUN"
    ESH = "ESH"
    IOT = "IOT"
    BDI = "BDI"
    COM = "COM"
    DJI = "DJI"
    ERI = "ERI"
    ETH = "ETH"
    ATF = "ATF"
    KEN = "KEN"
    MDG = "MDG"
    MWI = "MWI"
    MUS = "MUS"
    MYT = "MYT"
    MOZ = "MOZ"
    REU = "REU"
    RWA = "RWA"
    SYC = "SYC"
    SOM = "SOM"
    SSD = "SSD"
    UGA = "UGA"
    TZA = "TZA"
    ZMB = "ZMB"
    ZWE = "ZWE"
    AGO = "AGO"
    CMR = "CMR"
    CAF = "CAF"
    TCD = "TCD"
    COG = "COG"
    COD = "COD"
    GNQ = "GNQ"
    GAB = "GAB"
    STP = "STP"
    BWA = "BWA"
    LSO = "LSO"
    NAM = "NAM"
    ZAF = "ZAF"
    SWZ = "SWZ"
    BEN = "BEN"
    BFA = "BFA"
    CPV = "CPV"
    CIV = "CIV"
    GMB = "GMB"
    GHA = "GHA"
    GIN = "GIN"
    GNB = "GNB"
    LBR = "LBR"
    MLI = "MLI"
    MRT = "MRT"
    NER = "NER"
    NGA = "NGA"
    SHN = "SHN"
    SEN = "SEN"
    SLE = "SLE"
    TGO = "TGO"
    AIA = "AIA"
    ATG = "ATG"
    ABW = "ABW"
    BHS = "BHS"
    BRB = "BRB"
    BES = "BES"
    VGB = "VGB"
    CYM = "CYM"
    CUB = "CUB"
    CUW = "CUW"
    DMA = "DMA"
    DOM = "DOM"
    GRD = "GRD"
    GLP = "GLP"
    HTI = "HTI"
    JAM = "JAM"
    MTQ = "MTQ"
    MSR = "MSR"
    PRI = "PRI"
    BLM = "BLM"
    KNA = "KNA"
    LCA = "LCA"
    MAF = "MAF"
    VCT = "VCT"
    SXM = "SXM"
    TTO = "TTO"
    TCA = "TCA"
    VIR = "VIR"
    BLZ = "BLZ"
    CRI = "CRI"
    SLV = "SLV"
    GTM = "GTM"
    HND = "HND"
    MEX = "MEX"
    NIC = "NIC"
    PAN = "PAN"
    ARG = "ARG"
    BOL = "BOL"
    BRA = "BRA"
    CHL = "CHL"
    COL = "COL"
    ECU = "ECU"
    FLK = "FLK"
    GUF = "GUF"
    GUY = "GUY"
    PRY = "PRY"
    PER = "PER"
    SGS = "SGS"
    SUR = "SUR"
    URY = "URY"
    VEN = "VEN"
    BMU = "BMU"
    CAN = "CAN"
    GRL = "GRL"
    SPM = "SPM"
    USA = "USA"
    ATA = "ATA"
    KAZ = "KAZ"
    KGZ = "KGZ"
    TJK = "TJK"
    TKM = "TKM"
    UZB = "UZB"
    CHN = "CHN"
    HKG = "HKG"
    MAC = "MAC"
    PRK = "PRK"
    JPN = "JPN"
    MNG = "MNG"
    KOR = "KOR"
    BRN = "BRN"
    KHM = "KHM"
    IDN = "IDN"
    LAO = "LAO"
    MYS = "MYS"
    MMR = "MMR"
    PHL = "PHL"
    SGP = "SGP"
    THA = "THA"
    TLS = "TLS"
    VNM = "VNM"
    AFG = "AFG"
    BGD = "BGD"
    BTN = "BTN"
    IND = "IND"
    IRN = "IRN"
    MDV = "MDV"
    NPL = "NPL"
    PAK = "PAK"
    LKA = "LKA"
    ARM = "ARM"
    AZE = "AZE"
    BHR = "BHR"
    CYP = "CYP"
    GEO = "GEO"
    IRQ = "IRQ"
    ISR = "ISR"
    JOR = "JOR"
    KWT = "KWT"
    LBN = "LBN"
    OMN = "OMN"
    QAT = "QAT"
    SAU = "SAU"
    PSE = "PSE"
    SYR = "SYR"
    TUR = "TUR"
    ARE = "ARE"
    YEM = "YEM"
    BLR = "BLR"
    BGR = "BGR"
    CZE = "CZE"
    HUN = "HUN"
    POL = "POL"
    MDA = "MDA"
    ROU = "ROU"
    RUS = "RUS"
    SVK = "SVK"
    UKR = "UKR"
    ALA = "ALA"
    GGY = "GGY"
    JEY = "JEY"
    DNK = "DNK"
    EST = "EST"
    FRO = "FRO"
    FIN = "FIN"
    ISL = "ISL"
    IRL = "IRL"
    IMN = "IMN"
    LVA = "LVA"
    LTU = "LTU"
    NOR = "NOR"
    SJM = "SJM"
    SWE = "SWE"
    GBR = "GBR"
    ALB = "ALB"
    AND = "AND"
    BIH = "BIH"
    HRV = "HRV"
    GIB = "GIB"
    GRC = "GRC"
    VAT = "VAT"
    ITA = "ITA"
    MLT = "MLT"
    MNE = "MNE"
    PRT = "PRT"
    SMR = "SMR"
    SRB = "SRB"
    SVN = "SVN"
    ESP = "ESP"
    AUT = "AUT"
    BEL = "BEL"
    FRA = "FRA"
    DEU = "DEU"
    LIE = "LIE"
    LUX = "LUX"
    MCO = "MCO"
    NLD = "NLD"
    CHE = "CHE"
    AUS = "AUS"
    CXR = "CXR"
    CCK = "CCK"
    HMD = "HMD"
    NZL = "NZL"
    NFK = "NFK"
    FJI = "FJI"
    NCL = "NCL"
    PNG = "PNG"
    SLB = "SLB"
    VUT = "VUT"
    GUM = "GUM"
    KIR = "KIR"
    MHL = "MHL"
    FSM = "FSM"
    NRU = "NRU"
    MNP = "MNP"
    PLW = "PLW"
    UMI = "UMI"
    ASM = "ASM"
    COK = "COK"
    PYF = "PYF"
    NIU = "NIU"
    PCN = "PCN"
    WSM = "WSM"
    TKL = "TKL"
    TON = "TON"
    TUV = "TUV"
    WLF = "WLF"
    NN = "NN"



from __future__ import annotations

from dataclasses import dataclass, field

from pysifen.CommonMixin import CommonMixin

__NAMESPACE__ = "http://ekuatia.set.gov.py/sifen/xsd"


@dataclass(kw_only=True)
class TgResProc(CommonMixin):
    """
    Grupo Resultado de Procesamiento.
    """

    class Meta:
        name = "tgResProc"

    dCodRes: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"[0-9]{4}",
        }
    )
    dMsgRes: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 1,
            "max_length": 255,
        }
    )


@dataclass(kw_only=True)
class TgResProcEve(CommonMixin):
    """
    Grupo de resultado de procesamiento.
    """

    class Meta:
        name = "tgResProcEVe"

    dEstRes: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 8,
            "max_length": 30,
        }
    )
    dProtAut: None | int = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )
    id: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_inclusive": "0",
            "max_inclusive": "9999999999",
            "pattern": r"[0-9]{1,10}",
        }
    )
    gResProc: list[TgResProc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_occurs": 1,
            "max_occurs": 100,
        },
    )



from __future__ import annotations

from dataclasses import dataclass, field
from decimal import Decimal

from pysifen.CommonMixin import CommonMixin

__NAMESPACE__ = "http://ekuatia.set.gov.py/sifen/xsd"


@dataclass(kw_only=True)
class REnvioLote(CommonMixin):
    """
    Recepcion de Documentos Electronicos por Lote.

    :ivar dId: Identificador de control de envio
    :ivar xDE: XML del Documento Electronico Transferido
    """

    class Meta:
        name = "rEnvioLote"
        namespace = "http://ekuatia.set.gov.py/sifen/xsd"

    dId: int = field(
        metadata={
            "type": "Element",
            "min_inclusive": 1,
            "max_inclusive": 999999999999999,
        }
    )
    xDE: bytes = field(
        metadata={
            "type": "Element",
            "format": "base64",
        }
    )


@dataclass(kw_only=True)
class RResEnviLoteDe(CommonMixin):
    """
    Respuesta de la recepcion de Documentos Electronicos por Lote.

    :ivar dFecProc:
    :ivar dCodRes: Código del resultado de recepción
    :ivar dMsgRes: Mensaje del resultado de recepción
    :ivar dProtConsLote: Número de Lote
    :ivar dTpoProces: Tiempo medio de procesamiento en segundos
    """

    class Meta:
        name = "rResEnviLoteDe"
        namespace = "http://ekuatia.set.gov.py/sifen/xsd"

    dFecProc: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d[+|-]\d\d:\d\d",
        },
    )
    dCodRes: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "min_length": 1,
        },
    )
    dMsgRes: None | str = field(
        default=None,
        metadata={
            "type": "Element",
        },
    )
    dProtConsLote: None | Decimal = field(
        default=None,
        metadata={
            "type": "Element",
            "min_inclusive": Decimal("0"),
            "max_inclusive": Decimal("9999999999999999999999999999"),
            "total_digits": 28,
            "fraction_digits": 0,
        },
    )
    dTpoProces: None | int = field(
        default=None,
        metadata={
            "type": "Element",
        },
    )



"""Consultas ao SIFEN (DE, lote, RUC, DTE)."""
from __future__ import annotations

from decimal import Decimal

from pysifen.de.bindings.v150.ws_si_cons_de_v141 import (
    REnviConsDeRequest,
    REnviConsDeResponse,
)
from pysifen.de.bindings.v150.ws_si_cons_dte import (
    RConsDteRequest,
    RConsDteResponse,
)
from pysifen.de.bindings.v150.ws_si_cons_lote_v141 import (
    REnviConsLoteDe,
    RResEnviConsLoteDe,
)
from pysifen.de.bindings.v150.ws_si_cons_ruc_v141 import (
    REnviConsRuc,
    RResEnviConsRuc,
)
from pysifen.transmissao.base import TransmissaoBase


class ConsultaSIFEN(TransmissaoBase):
    """Consultas aos web services do SIFEN."""

    def consultar_de(self, cdc: str) -> REnviConsDeResponse:
        """Consulta DE por CDC (44 dígitos).

        Args:
            cdc: Código de Control (44 dígitos numéricos)

        Returns:
            REnviConsDeResponse com resultado da consulta
        """
        if len(cdc) != 44 or not cdc.isdigit():
            raise ValueError(
                f"CDC deve ter 44 dígitos numéricos. "
                f"Recebido: '{cdc}' ({len(cdc)} chars)"
            )

        request = REnviConsDeRequest(
            dId=_generate_id(),
            dCDC=cdc,
        )

        client = self._get_client("cons_de")
        response = client.send(request)

        if isinstance(response, REnviConsDeResponse):
            return response

        return self._parse(
            response if isinstance(response, str)
            else response.decode(),
            REnviConsDeResponse,
        )

    def consultar_lote(
        self, prot_lote: int | Decimal
    ) -> RResEnviConsLoteDe:
        """Consulta resultado de lote pelo protocolo.

        Args:
            prot_lote: número de protocolo do lote

        Returns:
            RResEnviConsLoteDe com resultado por DE
        """
        request = REnviConsLoteDe(
            dId=_generate_id(),
            dProtConsLote=Decimal(str(prot_lote)),
        )

        client = self._get_client("cons_lote")
        response = client.send(request)

        if isinstance(response, RResEnviConsLoteDe):
            return response

        return self._parse(
            response if isinstance(response, str)
            else response.decode(),
            RResEnviConsLoteDe,
        )

    def consultar_ruc(self, ruc: str) -> RResEnviConsRuc:
        """Consulta dados de contribuinte por RUC.

        Args:
            ruc: número de RUC (5-8 caracteres)

        Returns:
            RResEnviConsRuc com dados do contribuinte
        """
        if not (5 <= len(ruc) <= 8):
            raise ValueError(
                f"RUC deve ter entre 5 e 8 caracteres. "
                f"Recebido: '{ruc}' ({len(ruc)} chars)"
            )

        request = REnviConsRuc(
            dId=_generate_id(),
            dRUCCons=ruc,
        )

        client = self._get_client("cons_ruc")
        response = client.send(request)

        if isinstance(response, RResEnviConsRuc):
            return response

        return self._parse(
            response if isinstance(response, str)
            else response.decode(),
            RResEnviConsRuc,
        )

    def consultar_dte(
        self, consulta_dte
    ) -> RConsDteResponse:
        """Consulta DTE (Documento Tributário Eletrônico).

        Args:
            consulta_dte: instância de RConsultaDte

        Returns:
            RConsDteResponse com resultado
        """
        request = RConsDteRequest(
            rConsultaDTE=consulta_dte,
        )

        client = self._get_client("cons_dte")
        response = client.send(request)

        if isinstance(response, RConsDteResponse):
            return response

        return self._parse(
            response if isinstance(response, str)
            else response.decode(),
            RConsDteResponse,
        )


def _generate_id() -> int:
    """Gera ID de controle de envio baseado em timestamp."""
    import time

    return int(time.time() * 1000) % 999999999999999



"""Testes de leitura e escrita de Documentos Electrónicos (DE)."""
import os
import warnings
from decimal import Decimal

import pytest

warnings.filterwarnings("ignore")

SAMPLES_DIR = os.path.join(
    os.path.dirname(__file__), "..", "pysifen", "de", "samples", "v150"
)


@pytest.fixture
def factura_path():
    return os.path.join(SAMPLES_DIR, "factura_electronica.xml")


@pytest.fixture
def nota_credito_path():
    return os.path.join(SAMPLES_DIR, "nota_credito.xml")


@pytest.fixture
def autofactura_path():
    return os.path.join(SAMPLES_DIR, "autofactura.xml")


@pytest.fixture
def nota_remision_path():
    return os.path.join(SAMPLES_DIR, "nota_remision.xml")


class TestReadFactura:
    """Testes de leitura de Factura Electrónica (tipo 1)."""

    def test_parse_factura(self, factura_path):
        from pysifen.de.bindings.v150.fe_v141 import RDe

        rde = RDe.from_path(factura_path)
        assert rde is not None
        assert rde.dVerFor == "150"

    def test_factura_tipo(self, factura_path):
        from pysifen.de.bindings.v150.fe_v141 import RDe

        rde = RDe.from_path(factura_path)
        assert rde.DE.gTimb.iTiDE == "1"

    def test_factura_emisor(self, factura_path):
        from pysifen.de.bindings.v150.fe_v141 import RDe

        rde = RDe.from_path(factura_path)
        emis = rde.DE.gDatGralOpe.gEmis
        assert emis.dRucEm == "80069563"
        assert emis.dNomEmi == "Empresa Demo S.A."
        assert emis.dDirEmi == "Av. España 1234"
        assert emis.dEmailE == "demo@empresa.com.py"

    def test_factura_receptor(self, factura_path):
        from pysifen.de.bindings.v150.fe_v141 import RDe

        rde = RDe.from_path(factura_path)
        rec = rde.DE.gDatGralOpe.gDatRec
        assert rec.dRucRec == "4192083"
        assert rec.dNomRec == "Cliente Demo S.A."

    def test_factura_items(self, factura_path):
        from pysifen.de.bindings.v150.fe_v141 import RDe

        rde = RDe.from_path(factura_path)
        items = rde.DE.gDtipDE.gCamItem
        assert len(items) == 2
        assert items[0].dCodInt == "PROD001"
        assert items[0].dDesProSer == "Producto de prueba"
        assert items[1].dCodInt == "SERV001"

    def test_factura_totales(self, factura_path):
        from pysifen.de.bindings.v150.fe_v141 import RDe

        rde = RDe.from_path(factura_path)
        totais = rde.DE.gTotSub
        assert totais.dTotGralOpe == Decimal("1150000")
        assert totais.dSub10 == Decimal("1150000")
        assert totais.dIVA10 == Decimal("104545")

    def test_factura_iva(self, factura_path):
        from pysifen.de.bindings.v150.fe_v141 import RDe, TiAfecIva

        rde = RDe.from_path(factura_path)
        item = rde.DE.gDtipDE.gCamItem[0]
        assert item.gCamIVA.iAfecIVA == TiAfecIva.VALUE_1
        assert item.gCamIVA.dTasaIVA == Decimal("10")

    def test_factura_condicion_pago(self, factura_path):
        from pysifen.de.bindings.v150.fe_v141 import RDe, TiCondOpe

        rde = RDe.from_path(factura_path)
        cond = rde.DE.gDtipDE.gCamCond
        assert cond.iCondOpe == TiCondOpe.VALUE_1
        assert len(cond.gPaConEIni) == 1
        assert cond.gPaConEIni[0].dMonTiPag == Decimal("1150000")

    def test_factura_campos_futuro(self, factura_path):
        from pysifen.de.bindings.v150.fe_v141 import RDe

        rde = RDe.from_path(factura_path)
        assert rde.gCamFuFD is not None
        assert "ekuatia.set.gov.py" in rde.gCamFuFD.dCarQR


class TestReadNotaCredito:
    """Testes de leitura de Nota de Crédito (tipo 5)."""

    def test_parse_nota_credito(self, nota_credito_path):
        from pysifen.de.bindings.v150.fe_v141 import RDe

        rde = RDe.from_path(nota_credito_path)
        assert rde.DE.gTimb.iTiDE == "5"

    def test_nota_credito_motivo(self, nota_credito_path):
        from pysifen.de.bindings.v150.fe_v141 import RDe, TiMotEmi

        rde = RDe.from_path(nota_credito_path)
        assert rde.DE.gDtipDE.gCamNCDE is not None
        assert rde.DE.gDtipDE.gCamNCDE.iMotEmi == TiMotEmi.VALUE_1

    def test_nota_credito_doc_associado(self, nota_credito_path):
        from pysifen.de.bindings.v150.fe_v141 import RDe

        rde = RDe.from_path(nota_credito_path)
        assoc = rde.DE.gCamDEAsoc
        assert assoc is not None
        assert len(assoc) > 0


class TestReadAutofactura:
    """Testes de leitura de Autofactura (tipo 4)."""

    def test_parse_autofactura(self, autofactura_path):
        from pysifen.de.bindings.v150.fe_v141 import RDe

        rde = RDe.from_path(autofactura_path)
        assert rde.DE.gTimb.iTiDE == "4"

    def test_autofactura_campos(self, autofactura_path):
        from pysifen.de.bindings.v150.fe_v141 import RDe

        rde = RDe.from_path(autofactura_path)
        ae = rde.DE.gDtipDE.gCamAE
        assert ae is not None
        assert ae.dNomVen == "Juan Vendedor Pérez"


class TestReadNotaRemision:
    """Testes de leitura de Nota de Remisión (tipo 7)."""

    def test_parse_nota_remision(self, nota_remision_path):
        from pysifen.de.bindings.v150.fe_v141 import RDe

        rde = RDe.from_path(nota_remision_path)
        assert rde.DE.gTimb.iTiDE == "7"

    def test_nota_remision_motivo(self, nota_remision_path):
        from pysifen.de.bindings.v150.fe_v141 import RDe

        rde = RDe.from_path(nota_remision_path)
        nre = rde.DE.gDtipDE.gCamNRE
        assert nre is not None
        # iMotEmiNR pode ser lista de enum ou enum direto
        mot = nre.iMotEmiNR
        if isinstance(mot, list):
            assert mot[0].value == 1
        else:
            assert mot.value == 1


class TestFromXml:
    """Testes de from_xml (string)."""

    def test_from_xml_string(self, factura_path):
        from pysifen.de.bindings.v150.fe_v141 import RDe

        with open(factura_path) as f:
            xml_string = f.read()
        rde = RDe.from_xml(xml_string)
        assert rde.DE.gDatGralOpe.gEmis.dRucEm == "80069563"


class TestSerialization:
    """Testes de serialização (to_xml) e round-trip."""

    def test_to_xml(self, factura_path):
        from pysifen.de.bindings.v150.fe_v141 import RDe

        rde = RDe.from_path(factura_path)
        xml = rde.to_xml()
        assert '<?xml version="1.0" encoding="UTF-8"?>' in xml
        assert "80069563" in xml
        assert "Empresa Demo" in xml

    def test_round_trip(self, factura_path):
        from pysifen.de.bindings.v150.fe_v141 import RDe

        rde1 = RDe.from_path(factura_path)
        xml = rde1.to_xml()
        rde2 = RDe.from_xml(xml)

        assert rde1.dVerFor == rde2.dVerFor
        assert rde1.DE.Id == rde2.DE.Id
        assert rde1.DE.gDatGralOpe.gEmis.dRucEm == rde2.DE.gDatGralOpe.gEmis.dRucEm
        assert rde1.DE.gDatGralOpe.gEmis.dNomEmi == rde2.DE.gDatGralOpe.gEmis.dNomEmi
        assert len(rde1.DE.gDtipDE.gCamItem) == len(rde2.DE.gDtipDE.gCamItem)
        assert rde1.DE.gTotSub.dTotGralOpe == rde2.DE.gTotSub.dTotGralOpe

    def test_round_trip_all_samples(self):
        from pysifen.de.bindings.v150.fe_v141 import RDe

        for filename in os.listdir(SAMPLES_DIR):
            if not filename.endswith(".xml"):
                continue
            path = os.path.join(SAMPLES_DIR, filename)
            rde1 = RDe.from_path(path)
            xml = rde1.to_xml()
            rde2 = RDe.from_xml(xml)
            assert rde1.DE.Id == rde2.DE.Id, f"Round-trip failed for {filename}"

    def test_to_xml_compact(self, factura_path):
        from pysifen.de.bindings.v150.fe_v141 import RDe

        rde = RDe.from_path(factura_path)
        xml_pretty = rde.to_xml(pretty_print=True)
        xml_compact = rde.to_xml(pretty_print=False)
        assert len(xml_compact) < len(xml_pretty)


class TestCommonMixin:
    """Testes do CommonMixin."""

    def test_mixin_methods_exist(self):
        from pysifen.de.bindings.v150.fe_v141 import RDe

        assert hasattr(RDe, "from_xml")
        assert hasattr(RDe, "from_path")
        assert hasattr(RDe, "to_xml")
        assert hasattr(RDe, "validate_xml")
        assert hasattr(RDe, "sign_xml")

    def test_mixin_on_sub_classes(self):
        from pysifen.de.bindings.v150.fe_v141 import TgEmis

        assert hasattr(TgEmis, "from_xml")
        assert hasattr(TgEmis, "to_xml")



"""Mixin comum para todos os bindings do SIFEN."""
import os
from pathlib import Path

from xsdata.formats.dataclass.parsers import XmlParser
from xsdata.formats.dataclass.serializers import XmlSerializer
from xsdata.formats.dataclass.serializers.config import SerializerConfig


class CommonMixin:
    """Mixin adicionado automaticamente pelo xsdata a todas as classes."""

    @classmethod
    def from_xml(cls, xml_string: str):
        """Deserializa um XML string em objeto Python."""
        parser = XmlParser()
        return parser.from_string(xml_string, cls)

    @classmethod
    def from_path(cls, file_path: str):
        """Deserializa um arquivo XML em objeto Python."""
        parser = XmlParser()
        return parser.from_path(Path(file_path), cls)

    def to_xml(self, pretty_print: bool = True) -> str:
        """Serializa o objeto Python em XML string."""
        config = SerializerConfig(
            pretty_print=pretty_print,
            xml_declaration=True,
            encoding="UTF-8",
        )
        serializer = XmlSerializer(config=config)
        return serializer.render(self)

    def validate_xml(self) -> list:
        """Valida o XML contra o schema XSD correspondente."""
        from lxml import etree

        xml_string = self.to_xml()
        xml_doc = etree.fromstring(xml_string.encode())

        module = self.__class__.__module__
        parts = module.split(".")
        # pysifen.de.bindings.v150.de_v150 -> pysifen/de/schemas/v150/
        schema_dir = os.path.join(
            os.path.dirname(os.path.abspath(__file__)),
            parts[1],  # "de"
            "schemas",
            parts[3],  # "v150"
        )
        schema_files = [f for f in os.listdir(schema_dir) if f.endswith(".xsd")]
        errors = []
        for schema_file in schema_files:
            try:
                schema_path = os.path.join(schema_dir, schema_file)
                with open(schema_path, "rb") as f:
                    schema_doc = etree.parse(f)
                schema = etree.XMLSchema(schema_doc)
                schema.assertValid(xml_doc)
                return []
            except etree.DocumentInvalid as e:
                errors = [str(err) for err in e.error_log]
            except Exception:
                continue
        return errors

    def sign_xml(self, xml, pkcs12_data, pkcs12_password, doc_id):
        """Assina o XML usando certificado PKCS12 (RSA-SHA256)."""
        try:
            from pysifen.assinatura import sign_xml
        except ImportError:
            raise ImportError(
                "Para assinar XML, instale: "
                "pip install sifen[sign]"
            )
        return sign_xml(xml, pkcs12_data, pkcs12_password, doc_id)



from __future__ import annotations

from dataclasses import dataclass, field

from pysifen.CommonMixin import CommonMixin
from pysifen.de.bindings.v150.evento_v150 import TgGroupGesEve
from pysifen.de.bindings.v150.prot_proces_eventos_v141 import TgResProcEve

__NAMESPACE__ = "http://ekuatia.set.gov.py/sifen/xsd"


@dataclass(kw_only=True)
class REnviEventoDe(CommonMixin):
    """
    Recepcion de Eventos de Documentos Electronicos.

    :ivar dId: Identificador de control de envio
    :ivar dEvReg: Evento a ser registrado
    """

    class Meta:
        name = "rEnviEventoDe"
        namespace = "http://ekuatia.set.gov.py/sifen/xsd"

    dId: int = field(
        metadata={
            "type": "Element",
            "total_digits": 15,
        }
    )
    dEvReg: REnviEventoDe.DEvReg = field(
        metadata={
            "type": "Element",
        }
    )

    @dataclass(kw_only=True)
    class DEvReg(CommonMixin):
        gGroupGesEve: TgGroupGesEve = field(
            metadata={
                "type": "Element",
            }
        )


@dataclass(kw_only=True)
class RRetEnviEventoDe(CommonMixin):
    """
    Respuesta de Eventos.

    :ivar dFecProc:
    :ivar gResProcEVe: Grupo Resultado de Procesamiento del Evento
    """

    class Meta:
        name = "rRetEnviEventoDe"
        namespace = "http://ekuatia.set.gov.py/sifen/xsd"

    dFecProc: str = field(
        metadata={
            "type": "Element",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d[+|-]\d\d:\d\d",
        }
    )
    gResProcEVe: list[TgResProcEve] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "min_occurs": 1,
            "max_occurs": 15,
        },
    )



from __future__ import annotations

from dataclasses import dataclass, field
from enum import Enum

from pysifen.CommonMixin import CommonMixin

__NAMESPACE__ = "http://ekuatia.set.gov.py/sifen/xsd"


@dataclass(kw_only=True)
class Prodid(CommonMixin):
    class Meta:
        name = "prodid"
        namespace = "http://ekuatia.set.gov.py/sifen/xsd"

    value: str = field(
        default="",
        metadata={
            "pattern": r"[0-9][0-9][0-9][0-9][0-9]",
        },
    )


class TcMotDet(Enum):
    """
    Código del motivo del evento Determinacion del DTE.
    """

    VALUE_1 = 1
    VALUE_2 = 2
    VALUE_3 = 3
    VALUE_4 = 4
    VALUE_5 = 5
    VALUE_6 = 6


class TcMotImp(Enum):
    """
    Código del motivo del evento Impugnacion del DTE.
    """

    VALUE_1 = 1
    VALUE_2 = 2
    VALUE_3 = 3
    VALUE_4 = 4
    VALUE_5 = 5


class TcMotOa(Enum):
    """
    Código del motivo del evento Objeto de Análisis.
    """

    VALUE_1 = 1
    VALUE_2 = 2
    VALUE_3 = 3
    VALUE_4 = 4
    VALUE_5 = 5


class TcMotPc(Enum):
    """
    Código del motivo del evento Proceso de Control.
    """

    VALUE_1 = 1
    VALUE_2 = 2
    VALUE_3 = 3
    VALUE_4 = 4


class TdMotDesDet(Enum):
    """
    Descripción del motivo del evento Determinacion del DTE.
    """

    APLICACI_N_DE_MULTA_AL_EMISOR = "Aplicación de multa al Emisor"
    APLICACI_N_DE_MULTA_AL_RECEPTOR = "Aplicación de multa al Receptor"
    CORRECCI_N_CR_DITO_FISCAL = "Corrección Crédito fiscal"
    CORRECCI_N_D_BITO_FISCAL = "Corrección Débito fiscal"
    ANULACI_N_DE_IMPUGNACI_N_POR_FALLO_JUDICIAL = (
        "Anulación de Impugnación por fallo judicial"
    )
    OTRO = "Otro"


class TdMotDesImp(Enum):
    """
    Descripción del motivo del evento Impugnacion del DTE.
    """

    OPERACIONES_NO_RECONOCIDAS_POR_EL_CONTRIBUYENTE_PROVEEDOR_O_CLIENTE = (
        "Operaciones no reconocidas por el contribuyente (proveedor o cliente)"
    )
    SIMULACI_N_DE_OPERACIONES = "Simulación de operaciones"
    INCONSISTENCIAS_DETECTADAS = "Inconsistencias detectadas"
    CONTENIDO_FALSO = "Contenido falso"
    OTROS = "Otros"


class TdMotDesOa(Enum):
    """
    Descripción del motivo del evento Objeto de Análisis.
    """

    OPERACIONES_NO_RECONOCIDAS_POR_EL_CONTRIBUYENTE = (
        "Operaciones no reconocidas por el contribuyente"
    )
    SIMULACI_N_DE_OPERACIONES = "Simulación de operaciones"
    OMISI_N_DE_INGRESOS = "Omisión de ingresos"
    PROVEEDORES_INCONSISTENTES = "Proveedores inconsistentes"
    OTROS = "Otros"


class TdMotDesPc(Enum):
    """
    Descripción del motivo del evento Proceso de Control.
    """

    PROCESO_DE_CONTROL_INTERNO = "Proceso de control Interno"
    PROCESO_DE_FISCALIZACI_N = "Proceso de Fiscalización"
    PROCESO_DE_COBRANZAS = "Proceso de Cobranzas"
    PROCESO_DE_DEVOLUCI_N_DE_CR_DITOS_FISCALES = (
        "Proceso de Devolución de Créditos Fiscales"
    )


class TdMotEv(Enum):
    """
    Motivo del Evento.
    """

    VALUE_1 = 1
    VALUE_2 = 2
    VALUE_3 = 3
    VALUE_4 = 4


class TdTipEnd(Enum):
    """
    Tipo de Endoso.
    """

    VALUE_1 = 1
    VALUE_2 = 2


class TdTipIdenVeh(Enum):
    """
    Tipo de identificación del vehículo.
    """

    VALUE_1 = 1
    VALUE_2 = 2


class TiTiDeev(Enum):
    """
    Tipo de documento electronico.
    """

    VALUE_1 = 1
    VALUE_2 = 2
    VALUE_3 = 3
    VALUE_4 = 4
    VALUE_5 = 5
    VALUE_6 = 6
    VALUE_7 = 7
    VALUE_8 = 8
    VALUE_9 = 9


class TiTipEve(Enum):
    """
    Tipo de Receptor.
    """

    VALUE_1 = 1
    VALUE_2 = 2


class TiTipFac(Enum):
    """
    Tipo de Factor.
    """

    VALUE_1 = 1



"""Testes de bindings de eventos do SIFEN."""
import warnings

warnings.filterwarnings("ignore")


class TestEventoBindings:
    """Verifica que os bindings de evento são importáveis e usáveis."""

    def test_import_evento_v150(self):
        from pysifen.de.bindings.v150.evento_v150 import TrEve

        assert hasattr(TrEve, "__dataclass_fields__")

    def test_import_evento_types(self):
        from pysifen.de.bindings.v150.evento_types_v150 import TiTipEve

        assert TiTipEve is not None

    def test_evento_cancelacion(self):
        from pysifen.de.bindings.v150.evento_v150 import TrGeVeCan

        fields = list(TrGeVeCan.__dataclass_fields__.keys())
        assert len(fields) > 0

    def test_evento_inutilizacion(self):
        from pysifen.de.bindings.v150.evento_v150 import TrGeVeInu

        fields = list(TrGeVeInu.__dataclass_fields__.keys())
        assert len(fields) > 0

    def test_evento_conformidad(self):
        from pysifen.de.bindings.v150.evento_v150 import TrGeVeConf

        fields = list(TrGeVeConf.__dataclass_fields__.keys())
        assert len(fields) > 0

    def test_evento_disconformidad(self):
        from pysifen.de.bindings.v150.evento_v150 import TrGeVeDisconf

        fields = list(TrGeVeDisconf.__dataclass_fields__.keys())
        assert len(fields) > 0

    def test_evento_nominacion(self):
        from pysifen.de.bindings.v150.evento_v150 import TrGeveNom

        fields = list(TrGeveNom.__dataclass_fields__.keys())
        assert len(fields) > 0

    def test_evento_mixin(self):
        from pysifen.de.bindings.v150.evento_v150 import TrEve

        assert hasattr(TrEve, "from_xml")
        assert hasattr(TrEve, "to_xml")



from __future__ import annotations

from dataclasses import dataclass, field
from decimal import Decimal

from pysifen.CommonMixin import CommonMixin
from pysifen.de.bindings.v150.prot_proces_eventos_v141 import TgResProc

__NAMESPACE__ = "http://ekuatia.set.gov.py/sifen/xsd"


@dataclass(kw_only=True)
class REnviConsLoteDe(CommonMixin):
    """
    Recepcion de Documentos Para Consulta de Lote.

    :ivar dId:
    :ivar dProtConsLote: Número de Lote
    :ivar dCDC:
    """

    class Meta:
        name = "rEnviConsLoteDe"
        namespace = "http://ekuatia.set.gov.py/sifen/xsd"

    dId: int = field(
        metadata={
            "type": "Element",
            "total_digits": 15,
        }
    )
    dProtConsLote: None | Decimal = field(
        default=None,
        metadata={
            "type": "Element",
            "min_inclusive": Decimal("0"),
            "max_inclusive": Decimal("9999999999999999999999999999"),
            "total_digits": 28,
            "fraction_digits": 0,
        },
    )
    dCDC: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "max_length": 50,
        },
    )


@dataclass(kw_only=True)
class TgResProcLote(CommonMixin):
    """
    Grupo de resultado de procesamiento.

    :ivar id: CDC del DE procesado
    :ivar dEstRes: Estado del resultado
    :ivar dProtAut: Número de transacción
    :ivar gResProc:
    """

    class Meta:
        name = "tgResProcLote"

    id: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 1,
            "max_length": 47,
        }
    )
    dEstRes: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 8,
            "max_length": 30,
        }
    )
    dProtAut: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"[0-9]{1,10}",
        },
    )
    gResProc: list[TgResProc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_occurs": 1,
            "max_occurs": 5,
        },
    )


@dataclass(kw_only=True)
class RResEnviConsLoteDe(CommonMixin):
    """
    Respuesta de la Consulta de Documentos Electronicos por Lote.

    :ivar dFecProc:
    :ivar dCodResLot: Código de resultado de procesamiento del lote
    :ivar dMsgResLot: Mensaje del resultado de recepción
    :ivar gResProcLote:
    """

    class Meta:
        name = "rResEnviConsLoteDe"
        namespace = "http://ekuatia.set.gov.py/sifen/xsd"

    dFecProc: str = field(
        metadata={
            "type": "Element",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d[+|-]\d\d:\d\d",
        }
    )
    dCodResLot: str = field(
        metadata={
            "type": "Element",
            "min_length": 1,
            "max_length": 4,
        }
    )
    dMsgResLot: str = field(
        metadata={
            "type": "Element",
            "min_length": 1,
            "max_length": 255,
        }
    )
    gResProcLote: list[TgResProcLote] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 50,
        },
    )



from __future__ import annotations

from dataclasses import dataclass, field
from decimal import Decimal
from enum import Enum

from pysifen.CommonMixin import CommonMixin
from pysifen.de.bindings.v150.de_types_v150 import (
    TdDesForPagValue,
    TdDtipIdrespDeValue,
    TiForPag,
)
from pysifen.de.bindings.v150.unidades_medida_v141 import (
    TcUniMed,
    TdDesUniMed,
)

__NAMESPACE__ = "http://ekuatia.set.gov.py/sifen/xsd"


class TgCamCargICarCarga(Enum):
    VALUE_1 = 1
    VALUE_2 = 2
    VALUE_3 = 3


class TgCamCargValue(Enum):
    MERCADER_AS_CON_CADENA_DE_FR_O = "Mercaderías con cadena de frío"
    CARGA_PELIGROSA = "Carga peligrosa"


@dataclass(kw_only=True)
class TgGrupPolSeg(CommonMixin):
    """
    Póliza de seguros.

    :ivar dPoliza:
    :ivar dUnidVig: Descripción de la unidad de tiempo de vigencia
    :ivar dVigencia:
    :ivar dNumPoliza: Número de la póliza
    :ivar dFecIniVig:
    :ivar dFecFinVig:
    :ivar dCodInt: Código interno del ítem
    """

    class Meta:
        name = "tgGrupPolSeg"

    dPoliza: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "max_length": 20,
            "white_space": "collapse",
        }
    )
    dUnidVig: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 3,
            "max_length": 15,
            "white_space": "collapse",
            "pattern": r".*[^\s].*",
        }
    )
    dVigencia: Decimal = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_inclusive": Decimal("0"),
            "max_inclusive": Decimal("99.9"),
            "total_digits": 3,
            "fraction_digits": 1,
        }
    )
    dNumPoliza: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 1,
            "max_length": 25,
            "white_space": "collapse",
            "pattern": r".*[^\s].*",
        }
    )
    dFecIniVig: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d",
        },
    )
    dFecFinVig: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d",
        },
    )
    dCodInt: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 1,
            "max_length": 50,
            "white_space": "collapse",
            "pattern": r".*[^\s].*",
        },
    )


@dataclass(kw_only=True)
class TgOblAfe(CommonMixin):
    """
    Grupo de campos que identifican las obligaciones afectadas.
    """

    class Meta:
        name = "tgOblAfe"

    cOblAfe: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "total_digits": 3,
            "white_space": "collapse",
            "pattern": r"[1-9][0-9][0-9]",
        }
    )
    dDesOblAfe: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 21,
            "max_length": 65,
            "white_space": "preserve",
            "pattern": r".*[^\s].*",
        }
    )


@dataclass(kw_only=True)
class TgValorRestaItem(CommonMixin):
    """
    Campos que describen los descuentos, anticipos y valor total por item.
    """

    class Meta:
        name = "tgValorRestaItem"

    dDescItem: None | Decimal = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_inclusive": Decimal("0"),
            "max_inclusive": Decimal("999999999999999.99999999"),
            "total_digits": 23,
            "fraction_digits": 8,
        },
    )
    dPorcDesIt: None | Decimal = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_inclusive": Decimal("0"),
            "max_inclusive": Decimal("100"),
            "total_digits": 11,
            "fraction_digits": 8,
        },
    )
    dDescGloItem: None | Decimal = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_inclusive": Decimal("0"),
            "max_inclusive": Decimal("999999999999999.99999999"),
            "total_digits": 23,
            "fraction_digits": 8,
        },
    )
    dAntPreUniIt: None | Decimal = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_inclusive": Decimal("0"),
            "max_inclusive": Decimal("999999999999999.99999999"),
            "total_digits": 23,
            "fraction_digits": 8,
        },
    )
    dAntGloPreUniIt: None | Decimal = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_inclusive": Decimal("0"),
            "max_inclusive": Decimal("999999999999999.99999999"),
            "total_digits": 23,
            "fraction_digits": 8,
        },
    )
    dTotOpeItem: Decimal = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_inclusive": Decimal("0"),
            "max_inclusive": Decimal("999999999999999.99999999"),
            "total_digits": 23,
            "fraction_digits": 8,
        }
    )
    dTotOpeGs: None | Decimal = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_inclusive": Decimal("0"),
            "max_inclusive": Decimal("999999999999999.99999999"),
            "total_digits": 23,
            "fraction_digits": 8,
        },
    )


@dataclass(kw_only=True)
class TgCamCarg(CommonMixin):
    """
    Campos generales de la carga.

    :ivar cUniMedTotVol:
    :ivar dDesUniMedTotVol:
    :ivar dTotVolMerc: Total volumen de la mercaderia
    :ivar cUniMedTotPes:
    :ivar dDesUniMedTotPes:
    :ivar dTotPesMerc: Total peso de la mercadería
    :ivar iCarCarga:
    :ivar dDesCarCarga:
    """

    class Meta:
        name = "tgCamCarg"

    cUniMedTotVol: None | TcUniMed = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )
    dDesUniMedTotVol: None | TdDesUniMed = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )
    dTotVolMerc: None | int = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "total_digits": 20,
        },
    )
    cUniMedTotPes: None | TcUniMed = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )
    dDesUniMedTotPes: None | TdDesUniMed = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )
    dTotPesMerc: None | int = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "total_digits": 20,
        },
    )
    iCarCarga: None | TgCamCargICarCarga = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )
    dDesCarCarga: None | TgCamCargValue = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )


@dataclass(kw_only=True)
class TgCamRde(CommonMixin):
    """
    Campos que componen el Recibo de Dinero Electrónico.

    :ivar iForPag:
    :ivar dDesForPag:
    :ivar dNumTrans: Número de Transacción
    :ivar dConc: Concepto/Observación
    :ivar dRucEntFin:
    :ivar dDvEntFin:
    :ivar dNomEntFin: Nombre o Razón Social de la Entidad Financiera
    :ivar dImpPag:
    """

    class Meta:
        name = "tgCamRDE"

    iForPag: TiForPag = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        }
    )
    dDesForPag: str | TdDesForPagValue = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "white_space": "preserve",
            "pattern": r".+",
        }
    )
    dNumTrans: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 3,
            "max_length": 10,
            "white_space": "collapse",
            "pattern": r".*[^\s].*",
        },
    )
    dConc: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 1,
            "max_length": 255,
            "white_space": "collapse",
            "pattern": r".*[^\s].*",
        }
    )
    dRucEntFin: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 5,
            "max_length": 8,
            "pattern": r"[1-9][0-9]*[0-9A-D]?",
        },
    )
    dDvEntFin: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "white_space": "collapse",
            "pattern": r"[0-9]",
        },
    )
    dNomEntFin: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 4,
            "max_length": 255,
            "white_space": "collapse",
            "pattern": r".*[^\s].*",
        },
    )
    dImpPag: Decimal = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_inclusive": Decimal("0"),
            "max_inclusive": Decimal("999999999999999.9999"),
            "total_digits": 19,
            "fraction_digits": 4,
        }
    )


@dataclass(kw_only=True)
class TgRespDe(CommonMixin):
    """
    Grupo de Campos que identifican al responsable de la generación del DE.
    """

    class Meta:
        name = "tgRespDE"

    iTipIDRespDE: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "white_space": "collapse",
            "pattern": r"[1-4]|9",
        }
    )
    dDTipIDRespDE: str | TdDtipIdrespDeValue = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "white_space": "preserve",
            "pattern": r".+",
        }
    )
    dNumIDRespDE: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"[0-9A-Za-z\-]{1,20}",
        }
    )
    dNomRespDE: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 1,
            "max_length": 60,
            "white_space": "preserve",
            "pattern": r".*[^\s].*",
        }
    )
    dCarRespDE: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 4,
            "max_length": 100,
            "white_space": "preserve",
            "pattern": r".*[^\s].*",
        }
    )



from __future__ import annotations

from dataclasses import dataclass, field
from decimal import Decimal

from pysifen.CommonMixin import CommonMixin
from pysifen.de.bindings.v150.evento_types_v150 import (
    TcMotDet,
    TcMotImp,
    TcMotOa,
    TcMotPc,
    TdMotDesDet,
    TdMotDesImp,
    TdMotDesOa,
    TdMotDesPc,
    TdMotEv,
    TdTipEnd,
    TdTipIdenVeh,
    TiTiDeev,
    TiTipEve,
    TiTipFac,
)
from pysifen.de.bindings.v150.fe_types_v141 import (
    TdDesModTrans,
    TdDtipDoc,
    TdDtipDocRec,
)
from pysifen.de.bindings.v150.paises_v100 import PaisType
from pysifen.de.bindings.v150.xmldsig_core_schema import Signature

__NAMESPACE__ = "http://ekuatia.set.gov.py/sifen/xsd"


@dataclass(kw_only=True)
class RGeEvenAntRem(CommonMixin):
    """
    Grupo de Datos que identifican al Evento anticipo ó remision.
    """

    class Meta:
        name = "rGeEvenAntRem"

    Id: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "length": 44,
            "pattern": r"[0-9]{2}([0-9]{7}[0-9A-D]?)[0-9]{34}",
        }
    )


@dataclass(kw_only=True)
class TrGeDeVtr(CommonMixin):
    """
    Grupo de Datos que identifican al Evento por actualización de datos del
    transporte.
    """

    class Meta:
        name = "trGeDeVTr"

    Id: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "length": 44,
            "pattern": r"[0-9]{2}([0-9]{7}[0-9A-D]?)[0-9]{34}",
        },
    )
    dMotEv: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "max_length": 10,
        },
    )
    cDepEnt: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "max_length": 10,
        },
    )
    dDesDepEnt: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d",
        },
    )
    cDisEnt: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d",
        },
    )
    dDesDisEnt: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d",
        },
    )
    cCiuEnt: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "length": 44,
            "pattern": r"[0-9]{2}([0-9]{7}[0-9A-D]?)[0-9]{34}",
        },
    )
    dDesCiuEnt: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "max_length": 10,
        },
    )
    dDirEnt: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "max_length": 10,
        },
    )
    dNumCas: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d",
        },
    )
    dCompDir1: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d",
        },
    )
    dNomChof: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d",
        },
    )
    dNumIDChof: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "length": 44,
            "pattern": r"[0-9]{2}([0-9]{7}[0-9A-D]?)[0-9]{34}",
        },
    )
    iNatTrans: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "max_length": 10,
        },
    )
    dRucTrans: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "max_length": 10,
        },
    )
    dDVTrans: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d",
        },
    )
    dNomTrans: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d",
        },
    )
    iTipIDTrans: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d",
        },
    )
    dDTipIDTrans: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "length": 44,
            "pattern": r"[0-9]{2}([0-9]{7}[0-9A-D]?)[0-9]{34}",
        },
    )
    dNumIDTrans: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "max_length": 10,
        },
    )
    iTipTrans: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "max_length": 10,
        },
    )
    dDesTipTrans: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d",
        },
    )
    iModTrans: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d",
        },
    )
    dDesModTrans: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d",
        },
    )
    dTiVehTras: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "length": 44,
            "pattern": r"[0-9]{2}([0-9]{7}[0-9A-D]?)[0-9]{34}",
        },
    )
    dMarVeh: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "max_length": 10,
        },
    )
    dTipIdenVeh: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "max_length": 10,
        },
    )
    dNroIDVeh: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d",
        },
    )
    dNroMatVeh: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d",
        },
    )


@dataclass(kw_only=True)
class TrGeDevCcff(CommonMixin):
    """
    Grupo de Datos que identifican al Evento de devolución de créditos
    fiscales - Cuestionado ó Devuelto.
    """

    class Meta:
        name = "trGeDevCCFF"

    Id: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "length": 44,
            "pattern": r"[0-9]{2}([0-9]{7}[0-9A-D]?)[0-9]{34}",
        }
    )
    dNumDevSol: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "max_length": 10,
        }
    )
    dNumDevInf: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "max_length": 10,
        }
    )
    dNumDevRes: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "max_length": 10,
        }
    )
    dFeEmiSol: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d",
        }
    )
    dFeEmiInf: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d",
        }
    )
    dFeEmiRes: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d",
        }
    )


@dataclass(kw_only=True)
class TrGeVeCcff(CommonMixin):
    """
    Grupo de Datos que identifican al Evento de créditos fiscales.
    """

    class Meta:
        name = "trGeVeCCFF"

    Id: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "length": 44,
            "pattern": r"[0-9]{2}([0-9]{7}[0-9A-D]?)[0-9]{34}",
        }
    )
    dNumTraCCFF: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "max_length": 10,
        }
    )
    dFeAceTraCCFF: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d",
        }
    )


@dataclass(kw_only=True)
class TrGeVeCan(CommonMixin):
    """
    Grupo de Datos que identifican al evento de Cancelación del DTE.
    """

    class Meta:
        name = "trGeVeCan"

    Id: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "length": 44,
            "pattern": r"[0-9]{2}([0-9]{7}[0-9A-D]?)[0-9]{34}",
        }
    )
    mOtEve: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 5,
            "max_length": 500,
        }
    )


@dataclass(kw_only=True)
class TrGeVeDisconf(CommonMixin):
    """
    Grupo de Datos que identifican al evento receptor Disconformidad.
    """

    class Meta:
        name = "trGeVeDisconf"

    Id: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "length": 44,
            "pattern": r"[0-9]{2}([0-9]{7}[0-9A-D]?)[0-9]{34}",
        }
    )
    mOtEve: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 5,
            "max_length": 500,
        }
    )


@dataclass(kw_only=True)
class TrGeVeRetAce(CommonMixin):
    """
    Grupo de Datos que identifican al Evento de retención.
    """

    class Meta:
        name = "trGeVeRetAce"

    Id: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "length": 44,
            "pattern": r"[0-9]{2}([0-9]{7}[0-9A-D]?)[0-9]{34}",
        }
    )
    dRuc: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 5,
            "max_length": 8,
            "pattern": r"[1-9][0-9]*[0-9A-D]?",
        }
    )
    dNumTimRet: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 8,
            "max_length": 8,
            "pattern": r"0+[1-9][0-9]*|[1-9]+[0-9]+",
        }
    )
    dEstRet: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 3,
            "pattern": r"[0-9]{3}",
        }
    )
    dPunExpRet: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 3,
            "pattern": r"[0-9]{3}",
        }
    )
    dNumDocRet: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 7,
            "max_length": 7,
            "pattern": r"0+[1-9][0-9]*|[1-9]+[0-9]+",
        }
    )
    dCodConRet: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "max_length": 40,
        }
    )
    dFeEmiRet: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d",
        }
    )
    dMonRet: Decimal = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_inclusive": Decimal("0"),
            "max_inclusive": Decimal("999999999999999.99999999"),
            "total_digits": 23,
            "fraction_digits": 8,
        }
    )


@dataclass(kw_only=True)
class TrGeVeRetAnu(CommonMixin):
    """
    Grupo de Datos que identifican al Evento de retención anulación.
    """

    class Meta:
        name = "trGeVeRetAnu"

    Id: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "length": 44,
            "pattern": r"[0-9]{2}([0-9]{7}[0-9A-D]?)[0-9]{34}",
        }
    )
    dRuc: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 5,
            "max_length": 8,
            "pattern": r"[1-9][0-9]*[0-9A-D]?",
        }
    )
    dNumTimRet: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 8,
            "max_length": 8,
            "pattern": r"0+[1-9][0-9]*|[1-9]+[0-9]+",
        }
    )
    dEstRet: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 3,
            "pattern": r"[0-9]{3}",
        }
    )
    dPunExpRet: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 3,
            "pattern": r"[0-9]{3}",
        }
    )
    dNumDocRet: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 7,
            "max_length": 7,
            "pattern": r"0+[1-9][0-9]*|[1-9]+[0-9]+",
        }
    )
    dCodConRet: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "max_length": 40,
        }
    )
    dFeEmiRet: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d",
        }
    )
    dFecAnRet: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d",
        }
    )
    dMonRet: Decimal = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_inclusive": Decimal("0"),
            "max_inclusive": Decimal("999999999999999.99999999"),
            "total_digits": 23,
            "fraction_digits": 8,
        }
    )


@dataclass(kw_only=True)
class TrGeveNom(CommonMixin):
    """
    Grupo de Datos que identifican al Evento de Nominación.

    :ivar Id:
    :ivar mOtEve:
    :ivar iNatRec:
    :ivar iTiOpe:
    :ivar cPaisRec:
    :ivar dDesPaisRe:
    :ivar iTiContRec:
    :ivar dRucRec:
    :ivar dDVRec:
    :ivar iTipIDRec:
    :ivar dDTipIDRec:
    :ivar dNumIDRec:
    :ivar dNomRec:
    :ivar dNomFanRec:
    :ivar dDirRec:
    :ivar dNumCasRec:
    :ivar cDepRec:
    :ivar dDesDepRec:
    :ivar cDisRec:
    :ivar dDesDisRec:
    :ivar cCiuRec:
    :ivar dDesCiuRec:
    :ivar dTelRec:
    :ivar dCelRec:
    :ivar dEmailRec:
    :ivar dCodCliente: Codigo del Cliente
    """

    class Meta:
        name = "trGEveNom"

    Id: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "length": 44,
            "pattern": r"[0-9]{2}([0-9]{7}[0-9A-D]?)[0-9]{34}",
        }
    )
    mOtEve: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 5,
            "max_length": 500,
        }
    )
    iNatRec: TiTipEve = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        }
    )
    iTiOpe: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "white_space": "preserve",
            "pattern": r"[1-2]|[4]",
        }
    )
    cPaisRec: PaisType = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        }
    )
    dDesPaisRe: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 4,
            "max_length": 30,
            "white_space": "preserve",
            "pattern": r".*[^\s].*",
        }
    )
    iTiContRec: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "white_space": "collapse",
            "pattern": r"[1-2]",
        },
    )
    dRucRec: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 5,
            "max_length": 8,
            "pattern": r"[1-9][0-9]*[0-9A-D]?",
        },
    )
    dDVRec: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "white_space": "collapse",
            "pattern": r"[0-9]",
        },
    )
    iTipIDRec: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "white_space": "collapse",
            "pattern": r"[1-5]",
        },
    )
    dDTipIDRec: None | TdDtipDocRec = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )
    dNumIDRec: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"[0-9A-Za-z\-]{1,20}",
        },
    )
    dNomRec: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 4,
            "max_length": 255,
        }
    )
    dNomFanRec: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 4,
            "max_length": 255,
        },
    )
    dDirRec: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 1,
            "max_length": 255,
        },
    )
    dNumCasRec: None | int = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_inclusive": 0,
            "total_digits": 6,
        },
    )
    cDepRec: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_inclusive": "1",
            "max_inclusive": "99",
            "pattern": r"[0-9]{1,2}",
        },
    )
    dDesDepRec: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 6,
            "max_length": 16,
        },
    )
    cDisRec: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_inclusive": "1",
            "max_inclusive": "9999",
            "pattern": r"[0-9]{1,4}",
        },
    )
    dDesDisRec: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 1,
            "max_length": 30,
        },
    )
    cCiuRec: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_inclusive": "1",
            "max_inclusive": "99999",
            "pattern": r"[0-9]{1,5}",
        },
    )
    dDesCiuRec: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 1,
            "max_length": 30,
        },
    )
    dTelRec: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{8,15}",
        },
    )
    dCelRec: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{10,20}",
        },
    )
    dEmailRec: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"([0-9a-zA-Z#$%]([-.\w]*[0-9a-zA-Z#$%'\.\-_])*@([0-9a-zA-Z][-\w]*[0-9a-zA-Z]\.)+[a-zA-Z]{2,9})",
        },
    )
    dCodCliente: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 3,
            "max_length": 15,
            "white_space": "collapse",
        },
    )


@dataclass(kw_only=True)
class TrGeVeConf(CommonMixin):
    """
    Grupo de Datos que identifican al evento receptor Conformidad.
    """

    class Meta:
        name = "trGeVeConf"

    Id: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "length": 44,
            "pattern": r"[0-9]{2}([0-9]{7}[0-9A-D]?)[0-9]{34}",
        }
    )
    iTipConf: TiTipEve = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        }
    )
    dFecRecep: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d",
        },
    )


@dataclass(kw_only=True)
class TrGeVeDescon(CommonMixin):
    """
    Grupo de Datos que identifican al evento receptor Desconocimiento.
    """

    class Meta:
        name = "trGeVeDescon"

    Id: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "length": 44,
            "pattern": r"[0-9]{2}([0-9]{7}[0-9A-D]?)[0-9]{34}",
        }
    )
    dFecEmi: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d",
        }
    )
    dFecRecep: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d",
        }
    )
    iTipRec: TiTipEve = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        }
    )
    dNomRec: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 4,
            "max_length": 255,
        }
    )
    dRucRec: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 5,
            "max_length": 8,
            "pattern": r"[1-9][0-9]*[0-9A-D]?",
        },
    )
    dDVRec: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "white_space": "collapse",
            "pattern": r"[0-9]",
        },
    )
    dTipIDRec: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "white_space": "collapse",
            "pattern": r"[1-4]",
        },
    )
    dNumID: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"[0-9A-Za-z\-]{1,20}",
        },
    )
    mOtEve: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 5,
            "max_length": 500,
        }
    )


@dataclass(kw_only=True)
class TrGeVeDet(CommonMixin):
    """
    Grupo de Datos que identifican al Evento Origen Set Determinacion del
    DTE.
    """

    class Meta:
        name = "trGeVeDet"

    Id: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "length": 44,
            "pattern": r"[0-9]{2}([0-9]{7}[0-9A-D]?)[0-9]{34}",
        }
    )
    dFechaDet: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\d",
        }
    )
    cMotDet: TcMotDet = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        }
    )
    dMotDesDet: TdMotDesDet = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        }
    )
    dObsEveDet: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 1,
            "max_length": 500,
        },
    )


@dataclass(kw_only=True)
class TrGeVeEnd(CommonMixin):
    """
    Grupo de Datos que identifican al Evento de Endoso.
    """

    class Meta:
        name = "trGeVeEnd"

    Id: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "length": 44,
            "pattern": r"[0-9]{2}([0-9]{7}[0-9A-D]?)[0-9]{34}",
        }
    )
    iTipRec: TiTipEve = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        }
    )
    dNomRec: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 4,
            "max_length": 255,
        }
    )
    dRucRec: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 5,
            "max_length": 8,
            "pattern": r"[1-9][0-9]*[0-9A-D]?",
        },
    )
    dDVRec: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "white_space": "collapse",
            "pattern": r"[0-9]",
        },
    )
    dTipIDRec: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "white_space": "collapse",
            "pattern": r"[1-4]",
        },
    )
    dNumIDRec: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"[0-9A-Za-z\-]{1,20}",
        },
    )
    dRucEmi: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 5,
            "max_length": 8,
            "pattern": r"[1-9][0-9]*[0-9A-D]?",
        }
    )
    dDVEmi: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "white_space": "collapse",
            "pattern": r"[0-9]",
        }
    )
    dNomEmi: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 4,
            "max_length": 255,
        }
    )
    dTipEnd: TdTipEnd = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        }
    )
    iTipFac: TiTipFac = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        }
    )
    dNomFac: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 4,
            "max_length": 255,
        }
    )
    dRucFac: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 5,
            "max_length": 8,
            "pattern": r"[1-9][0-9]*[0-9A-D]?",
        }
    )
    dDVFac: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "white_space": "collapse",
            "pattern": r"[0-9]",
        }
    )
    dNumCon: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 1,
            "max_length": 50,
        },
    )
    dNumRegPubCon: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 1,
            "max_length": 50,
        },
    )
    dTotalGs: Decimal = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_inclusive": Decimal("0"),
            "max_inclusive": Decimal("999999999999999.99999999"),
            "total_digits": 23,
            "fraction_digits": 8,
        }
    )
    dPorDes: Decimal = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_inclusive": Decimal("0"),
            "max_inclusive": Decimal("999.99999999"),
            "total_digits": 11,
            "fraction_digits": 8,
        }
    )
    dMonDesMonExt: None | Decimal = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_inclusive": Decimal("0"),
            "max_inclusive": Decimal("999999999999999.99999999"),
            "total_digits": 23,
            "fraction_digits": 8,
        },
    )
    dTipCamDesMonExt: None | Decimal = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_inclusive": Decimal("0"),
            "max_inclusive": Decimal("999999999999999.99999999"),
            "total_digits": 23,
            "fraction_digits": 8,
        },
    )
    dMonDesGs: Decimal = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_inclusive": Decimal("0"),
            "max_inclusive": Decimal("999999999999999.99999999"),
            "total_digits": 23,
            "fraction_digits": 8,
        }
    )
    dTotOpeEndGs: Decimal = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_inclusive": Decimal("0"),
            "max_inclusive": Decimal("999999999999999.99999999"),
            "total_digits": 23,
            "fraction_digits": 8,
        }
    )


@dataclass(kw_only=True)
class TrGeVeImp(CommonMixin):
    """
    Grupo de Datos que identifican al Evento Origen Set Impugnacion del
    DTE.
    """

    class Meta:
        name = "trGeVeImp"

    Id: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "length": 44,
            "pattern": r"[0-9]{2}([0-9]{7}[0-9A-D]?)[0-9]{34}",
        }
    )
    dFechaImp: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\d",
        }
    )
    cMotImp: TcMotImp = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        }
    )
    dMotDesImp: TdMotDesImp = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        }
    )
    dObsEveImp: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 1,
            "max_length": 500,
        },
    )


@dataclass(kw_only=True)
class TrGeVeInu(CommonMixin):
    """
    Grupo de Datos que identifican al evento de Inutilización de numero de
    un DE.
    """

    class Meta:
        name = "trGeVeInu"

    dNumTim: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 8,
            "max_length": 8,
            "pattern": r"0+[1-9][0-9]*|[1-9]+[0-9]+",
        }
    )
    dEst: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 3,
            "pattern": r"[0-9]{3}",
        }
    )
    dPunExp: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 3,
            "pattern": r"[0-9]{3}",
        }
    )
    dNumIn: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 7,
            "pattern": r"0+[1-9][0-9]*|[1-9]+[0-9]+",
        }
    )
    dNumFin: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 7,
            "pattern": r"0+[1-9][0-9]*|[1-9]+[0-9]+",
        }
    )
    iTiDE: TiTiDeev = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        }
    )
    mOtEve: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 5,
            "max_length": 500,
        }
    )
    dSerieNum: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 2,
            "max_length": 2,
            "pattern": r"[A-Z][A-Z]",
        },
    )


@dataclass(kw_only=True)
class TrGeVeNotRec(CommonMixin):
    """
    Grupo de Datos que identifican al evento receptor Notificación -
    Recepción de un DE/DTE.
    """

    class Meta:
        name = "trGeVeNotRec"

    Id: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "length": 44,
            "pattern": r"[0-9]{2}([0-9]{7}[0-9A-D]?)[0-9]{34}",
        }
    )
    dFecEmi: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d",
        }
    )
    dFecRecep: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d",
        }
    )
    iTipRec: TiTipEve = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        }
    )
    dNomRec: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 4,
            "max_length": 255,
        }
    )
    dRucRec: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 5,
            "max_length": 8,
            "pattern": r"[1-9][0-9]*[0-9A-D]?",
        },
    )
    dDVRec: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "white_space": "collapse",
            "pattern": r"[0-9]",
        },
    )
    dTipIDRec: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "white_space": "collapse",
            "pattern": r"[1-5]",
        },
    )
    dNumID: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"[0-9A-Za-z\-]{1,20}",
        },
    )
    dTotalGs: Decimal = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_inclusive": Decimal("0"),
            "max_inclusive": Decimal("999999999999999.99999999"),
            "total_digits": 23,
            "fraction_digits": 8,
        }
    )


@dataclass(kw_only=True)
class TrGeVeOa(CommonMixin):
    """
    Grupo de Datos que identifican al Evento Origen Set Objeto de Analisis.
    """

    class Meta:
        name = "trGeVeOA"

    Id: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "length": 44,
            "pattern": r"[0-9]{2}([0-9]{7}[0-9A-D]?)[0-9]{34}",
        }
    )
    dFechaOA: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\d",
        }
    )
    cMotOA: TcMotOa = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        }
    )
    dMotDesOA: TdMotDesOa = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        }
    )
    dObsOA: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 1,
            "max_length": 500,
        },
    )


@dataclass(kw_only=True)
class TrGeVePc(CommonMixin):
    """
    Grupo de Datos que identifican al Evento Origen Set Proceso de Control.
    """

    class Meta:
        name = "trGeVePC"

    Id: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "length": 44,
            "pattern": r"[0-9]{2}([0-9]{7}[0-9A-D]?)[0-9]{34}",
        }
    )
    dFechaPC: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\d",
        }
    )
    cMotPC: TcMotPc = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        }
    )
    dMotDesPC: TdMotDesPc = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        }
    )
    dObsEvePC: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 1,
            "max_length": 500,
        },
    )


@dataclass(kw_only=True)
class TrGeVeTr(CommonMixin):
    """
    Grupo de Datos que identifican al Evento de Transporte.
    """

    class Meta:
        name = "trGeVeTr"

    Id: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "length": 44,
            "pattern": r"[0-9]{2}([0-9]{7}[0-9A-D]?)[0-9]{34}",
        }
    )
    dMotEv: TdMotEv = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        }
    )
    cDepEnt: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_inclusive": "1",
            "max_inclusive": "99",
            "pattern": r"[0-9]{1,2}",
        },
    )
    dDesDepEnt: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 6,
            "max_length": 16,
        },
    )
    cDisEnt: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_inclusive": "1",
            "max_inclusive": "9999",
            "pattern": r"[0-9]{1,4}",
        },
    )
    dDesDisEnt: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 1,
            "max_length": 30,
        },
    )
    cCiuEnt: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_inclusive": "1",
            "max_inclusive": "99999",
            "pattern": r"[0-9]{1,5}",
        },
    )
    dDesCiuEnt: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 1,
            "max_length": 30,
        },
    )
    dDirEnt: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 1,
            "max_length": 255,
        },
    )
    dNumCas: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_inclusive": "0",
            "max_inclusive": "999999",
            "pattern": r"[0-9]{1,6}",
        },
    )
    dCompDir1: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 1,
            "max_length": 255,
        },
    )
    dNomChof: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 4,
            "max_length": 255,
        },
    )
    dNumIDChof: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"[0-9A-Za-z\-]{1,20}",
        },
    )
    iNatTrans: None | TiTipEve = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )
    dRucTrans: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 5,
            "max_length": 8,
            "pattern": r"[1-9][0-9]*[0-9A-D]?",
        },
    )
    dDVTrans: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "white_space": "collapse",
            "pattern": r"[0-9]",
        },
    )
    dNomTrans: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 4,
            "max_length": 255,
        },
    )
    iTipIDTrans: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "white_space": "collapse",
            "pattern": r"[1-4]",
        },
    )
    dDTipIDTrans: None | TdDtipDoc = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )
    dNumIDTrans: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"[0-9A-Za-z\-]{1,20}",
        },
    )
    iTipTrans: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "white_space": "collapse",
            "pattern": r"[1-2]",
        },
    )
    dDesTipTrans: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 6,
            "max_length": 7,
        },
    )
    iModTrans: None | TdMotEv = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )
    dDesModTrans: None | TdDesModTrans = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )
    dTiVehTras: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 4,
            "max_length": 10,
        },
    )
    dMarVeh: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 1,
            "max_length": 10,
        },
    )
    dTipIdenVeh: None | TdTipIdenVeh = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )
    dNroIDVeh: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_length": 1,
            "max_length": 20,
        },
    )
    dNroMatVeh: None | str = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "length": 6,
        },
    )


@dataclass(kw_only=True)
class TgGroupEvt(CommonMixin):
    """
    Grupo del evento.
    """

    class Meta:
        name = "tgGroupEvt"

    rGeVeCan: None | TrGeVeCan = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )
    rGeVeInu: None | TrGeVeInu = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )
    rGeVeNotRec: None | TrGeVeNotRec = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )
    rGeVeConf: None | TrGeVeConf = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )
    rGeVeDisconf: None | TrGeVeDisconf = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )
    rGeVeDescon: None | TrGeVeDescon = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )
    rGeVeEnd: None | TrGeVeEnd = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )
    rGeVeTr: None | TrGeVeTr = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )
    rGEveNom: None | TrGeveNom = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )


@dataclass(kw_only=True)
class TgGroupEvtEmi(CommonMixin):
    """
    Grupo del evento Emisores.
    """

    class Meta:
        name = "tgGroupEvtEmi"

    rGeVeRetAce: None | TrGeVeRetAce = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )
    rGeVeRetAnu: None | TrGeVeRetAnu = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )
    rGeVeCCFF: None | TrGeVeCcff = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )
    rGeDevCCFFCue: None | TrGeDevCcff = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )
    rGeDevCCFFDev: None | TrGeDevCcff = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )
    rGeVeAnt: None | RGeEvenAntRem = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )
    rGeVeRem: None | RGeEvenAntRem = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )
    rGEveNom: None | TrGeveNom = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )


@dataclass(kw_only=True)
class TgGroupEvtRecep(CommonMixin):
    """
    Grupo del evento Receptores.
    """

    class Meta:
        name = "tgGroupEvtRecep"

    rGeVeNotRec: None | TrGeVeNotRec = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )
    rGeVeConf: None | TrGeVeConf = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )
    rGeVeDisconf: None | TrGeVeDisconf = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )
    rGeVeDescon: None | TrGeVeDescon = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )


@dataclass(kw_only=True)
class TgGroupEvtSet(CommonMixin):
    """
    Grupo del evento Origen SET.
    """

    class Meta:
        name = "tgGroupEvtSet"

    rGeVeOA: None | TrGeVeOa = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )
    rGeVePC: None | TrGeVePc = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )
    rGeVeImp: None | TrGeVeImp = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )
    rGeVeDet: None | TrGeVeDet = field(
        default=None,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        },
    )


@dataclass(kw_only=True)
class TrEve(CommonMixin):
    class Meta:
        name = "trEve"

    dFecFirma: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d",
        }
    )
    dVerFor: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "total_digits": 3,
            "pattern": r"[1][4][1]|[1][5][0]",
        }
    )
    gGroupTiEvt: TgGroupEvt = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        }
    )
    Id: str = field(
        metadata={
            "type": "Attribute",
            "min_inclusive": "1",
            "max_inclusive": "9999999999",
            "pattern": r"[0-9]+",
        }
    )


@dataclass(kw_only=True)
class TrEveEmi(CommonMixin):
    class Meta:
        name = "trEveEmi"

    dFecFirma: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d",
        }
    )
    dVerFor: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "total_digits": 3,
            "pattern": r"[1][4][1]|[1][5][0]",
        }
    )
    gGroupTiEvt: TgGroupEvtEmi = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        }
    )


@dataclass(kw_only=True)
class TrEveRecep(CommonMixin):
    class Meta:
        name = "trEveRecep"

    dFecFirma: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d",
        }
    )
    dVerFor: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "total_digits": 3,
            "pattern": r"[1][4][1]|[1][5][0]",
        }
    )
    gGroupTiEvt: TgGroupEvtRecep = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        }
    )


@dataclass(kw_only=True)
class TrEveSet(CommonMixin):
    class Meta:
        name = "trEveSet"

    dFecFirma: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "pattern": r"\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d",
        }
    )
    dVerFor: str = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "total_digits": 3,
            "pattern": r"[1][4][1]|[1][5][0]",
        }
    )
    gGroupTiEvt: TgGroupEvtSet = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        }
    )


@dataclass(kw_only=True)
class TrGesEve(CommonMixin):
    """
    :ivar rEve:
    :ivar Signature: Firma Digital del DE
    """

    class Meta:
        name = "trGesEve"

    rEve: TrEve = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        }
    )
    Signature: Signature = field(
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/2000/09/xmldsig#",
        }
    )


@dataclass(kw_only=True)
class TrGesEveEmi(CommonMixin):
    class Meta:
        name = "trGesEveEmi"

    rEve: TrEveEmi = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        }
    )


@dataclass(kw_only=True)
class TrGesEveRecep(CommonMixin):
    class Meta:
        name = "trGesEveRecep"

    rEve: TrEveRecep = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        }
    )


@dataclass(kw_only=True)
class TrGesEveSet(CommonMixin):
    class Meta:
        name = "trGesEveSet"

    rEve: TrEveSet = field(
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
        }
    )


@dataclass(kw_only=True)
class TgGroupGesEve(CommonMixin):
    class Meta:
        name = "tgGroupGesEve"

    rGesEve: list[TrGesEve] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://ekuatia.set.gov.py/sifen/xsd",
            "min_occurs": 1,
            "max_occurs": 15,
        },
    )
